package cloud.proxi.proxicloud

import androidx.annotation.NonNull
import cloud.proxi.ProxiCloudSdk

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** ProxicloudsdkPlugin */
class ProxicloudPlugin : FlutterPlugin, MethodCallHandler {

    private lateinit var channel: MethodChannel

    private val proxiCloudSdk: ProxiCloudSdk = ProxiCloudSdk.getInstance()

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "proxicloudsdk")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "reportEvent" -> {
                proxiCloudSdk.reportEvent(
                    call.argument<String>("key")!!,
                    call.argument<String>("value")!!
                )
            }
            "setNotificationsEnabled" -> {
                proxiCloudSdk.setNotificationsEnabled(call.argument<Boolean>("enabled")!!)
            }
            "setAdvertisingIdentifier" -> {
                proxiCloudSdk.setAdvertisingIdentifier(call.argument<String>("advertisingIdentifier"))
            }
            "setGdprConsentGiven" -> {
                proxiCloudSdk.setGdprConsent(call.argument<Boolean>("consentGiven")!!)
            }
            "handleIabTcfConsentInfo" -> {
                proxiCloudSdk.handleIabTcfConsentInfo()
            }
            "setLogging" -> {
                proxiCloudSdk.setLogging(call.argument<Boolean>("loggingEnabled")!!)
            }
            "setDeepLinkActivityFlags" -> {
                proxiCloudSdk.setDeepLinkActivityLaunchFlags(call.argument<Int>("flags")!!)
            }
            "setAttribute" -> {
                proxiCloudSdk.setAttribute(
                    call.argument<String>("key")!!,
                    call.argument<String>("value")!!
                )
            }
            "removeAttribute" -> {
                proxiCloudSdk.removeAttribute(call.argument<String>("key"))
            }
            "removeAttributes" -> {
                proxiCloudSdk.removeAllAttributes()
            }
            "getAttributes" -> {
                result.success(proxiCloudSdk.attributes)
            }
            "setAPiKey" -> {

            }
            "requestLocationAuthorization" -> {

            }
            "setNotificationConversion" -> {

            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
