import Flutter
import UIKit
import ProxicloudSDK

public class SwiftProxicloudPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "proxicloud", binaryMessenger: registrar.messenger())
    let instance = SwiftProxicloudPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    result("iOS " + UIDevice.current.systemVersion)
    
    switch call.method {
    case "reportEvent":
        if (verifyArguments(call: call, result: result, keys: ["key", "value"])) {
            if let arguments = call.arguments,
                let arg = arguments as? [String: Any] {
                let key = arg["key"] as! String
                let value = arg["value"] as! String
                PCManager.shared().reportEvent(key, withValue: value)
            }
        }
        break
    case "setNotificationsEnabled":
        break
    case "setAdvertisingIdentifier":
        if (verifyArguments(call: call, result: result, keys: [ "advertisingIdentifier"])) {
            if let arguments = call.arguments, let arg = arguments as? [String: Any] {
                if let idfa: String = arg["advertisingIdentifier"] as? String {
                    PCManager.shared().setIDFAValue(idfa)
                }
            }
        }
        break
    case "setGdprConsentGiven":
        break
    case "handleIabTcfConsentInfo":
        break
    case "setLogging":
        break
    case "setDeepLinkActivityFlags":
        break
    case "setAttribute":
        break
    case "removeAttribute":
        break
    case "removeAttributes":
        break
    case "getAttributes":
         break
    case "setApiKey":
        if (verifyArguments(call: call, result: result, keys: [ "apiKey"])) {
            if let arguments = call.arguments, let arg = arguments as? [String: Any] {
                if let apiKey: String = arg["apiKey"] as? String {
                    PCManager.shared().setApiKey(apiKey, delegate: self)
                }
            }
        }
        break
    case "requestLocationAuthorization":
        if (verifyArguments(call: call, result: result, keys: [ "request"])) {
            if let arguments = call.arguments, let arg = arguments as? [String: Any] {
                if let request: Bool = arg["request"] as? Bool {
                    PCManager.shared().requestLocationAuthorization(request)
                }
            }
        }
        break
    case "setNotificationConversion":
        break
    default:
        result(FlutterMethodNotImplemented)
    }
    
  }
    
    func verifyArguments(call: FlutterMethodCall, result: @escaping FlutterResult, keys: [String]) -> Bool {
        if let arguments = call.arguments,
            let arg = arguments as? [String: Any] {
            for key in keys {
                if arg[key] == nil {
                    result(FlutterError(code: "ARGUMENT_ERRROR", message: "Key \(key) is empty", details: nil))
                    return false
                }
            }
        } else if (call.arguments == nil) {
            result(FlutterError(code: "ARGUMENT_ERRROR", message: "Arguement is empty", details: nil))
            return false
        }
        return true
    }
}
